#[repr(transparent)]pub struct PowerLevelSelectionRow {
inner: TypedObjectRef<PowerLevelSelectionRow, <PowerLevelSelectionRow as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
An AdwPreferencesRow behaving like a combo box to select a room member’s power level.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<PowerLevelSelectionRow, <PowerLevelSelectionRow as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl PowerLevelSelectionRow
impl PowerLevelSelectionRow
Sourcepub fn permissions(&self) -> <RefCell<Option<Permissions>> as Property>::Value
pub fn permissions(&self) -> <RefCell<Option<Permissions>> as Property>::Value
The permissions to watch.
Sourcepub fn set_permissions<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<Permissions>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_permissions<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<Permissions>> as Property>::Value as HasParamSpec>::SetValue>>, )
The permissions to watch.
Sourcepub fn use_subtitle(&self) -> <Cell<bool> as Property>::Value
pub fn use_subtitle(&self) -> <Cell<bool> as Property>::Value
Whether the selected power level should be displayed in the subtitle, rather than next to the combo arrow.
Sourcepub fn set_use_subtitle<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_use_subtitle<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the selected power level should be displayed in the subtitle, rather than next to the combo arrow.
Sourcepub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
pub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
Whether the row is loading.
Sourcepub fn set_is_loading<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_is_loading<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the row is loading.
Sourcepub fn set_read_only<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_read_only<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether the row is read-only.
Sourcepub fn connect_permissions_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_permissions_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the permissions property
Sourcepub fn connect_use_subtitle_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_use_subtitle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the use-subtitle property
Sourcepub fn connect_is_loading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-loading property
Sourcepub fn connect_read_only_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_read_only_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the read-only property
Sourcepub fn notify_permissions(&self)
pub fn notify_permissions(&self)
Notify listeners of a change in the permissions property
Sourcepub fn notify_use_subtitle(&self)
pub fn notify_use_subtitle(&self)
Notify listeners of a change in the use-subtitle property
Sourcepub fn notify_is_loading(&self)
pub fn notify_is_loading(&self)
Notify listeners of a change in the is-loading property
Sourcepub fn notify_read_only(&self)
pub fn notify_read_only(&self)
Notify listeners of a change in the read-only property
Sourceimpl PowerLevelSelectionRow
impl PowerLevelSelectionRow
pub fn new() -> Self
Sourcepub(crate) fn selected_power_level(&self) -> UserPowerLevel
pub(crate) fn selected_power_level(&self) -> UserPowerLevel
The selected power level.
Sourcepub(crate) fn set_selected_power_level(&self, power_level: UserPowerLevel)
pub(crate) fn set_selected_power_level(&self, power_level: UserPowerLevel)
Set the selected power level.
Sourcepub fn connect_power_level_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_power_level_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the selected power level changed.